window.Gleam.initSearch([{"doc":"rada","title":"rada","content":"# rada\n\nThis package provides a simple `Date` type for working with dates without times or zones.\n\n## Origins\n\nThis is a port of the [justinmimbs/date](https://package.elm-lang.org/packages/justinmimbs/date/latest) Elm library.\nDone with the kind permission of the author. The API has been adjusted to match norms of the Gleam language in places.\n\n## Installation\n\n```sh\ngleam add rada\n```\n\n## Usage\n\n```gleam\nimport gleam/io\nimport gleam/list\n\nimport rada/date\n\npub fn main() {\n  let today = date.today()\n  let one_week_later = date.add(today, 1, date.Weeks)\n\n  date.range(date.Day, 1, today, one_week_later)\n  |&gt; list.each(fn(entry)\n    date.format(entry, &quot;EEEE, d MMMM y&quot;) |&gt; io.println\n  })\n}\n```\n\nDocumentation can be found at &lt;https://hexdocs.pm/rada&gt;.\n\n","url":"index.html"},{"doc":"rada/date","title":"Date","content":"pub opaque type Date\n Represents a date.\n\n The internal storage is a single `Int` using the [Rata Die][ratadie] system. The\n number 1 represents the date **1 January 0001** and all other dates are represented\n as positive or negative numbers relative to that date.\n\n [ratadie]: https://en.wikipedia.org/wiki/Rata_Die\n\nSynonyms:\nrada/date.Date\nrada/date Date","url":"rada/date.html#Date"},{"doc":"rada/date","title":"Interval","content":"pub type Interval {\n  Year\n  Quarter\n  Month\n  Week\n  Monday\n  Tuesday\n  Wednesday\n  Thursday\n  Friday\n  Saturday\n  Sunday\n  Day\n}\n Interval indicator used in `floor`, `ceiling` and `range` functions. Allowing you to, for example, round a date\n down to the nearest quarter, or week, or Tuesday, or whatever is required.\nYear\n\n\nQuarter\n\n\nMonth\n\n\nWeek\n\n\nMonday\n\n\nTuesday\n\n\nWednesday\n\n\nThursday\n\n\nFriday\n\n\nSaturday\n\n\nSunday\n\n\nDay\n\n\nSynonyms:\nrada/date.Interval\nrada/date Interval","url":"rada/date.html#Interval"},{"doc":"rada/date","title":"Language","content":"pub type Language {\n  Language(\n    month_name: fn(Month) -&gt; String,\n    month_name_short: fn(Month) -&gt; String,\n    weekday_name: fn(Weekday) -&gt; String,\n    weekday_name_short: fn(Weekday) -&gt; String,\n    day_with_suffix: fn(Int) -&gt; String,\n  )\n}\n Functions to convert date information to strings in a custom language.\nLanguage(\n  month_name: fn(Month) -&gt; String,\n  month_name_short: fn(Month) -&gt; String,\n  weekday_name: fn(Weekday) -&gt; String,\n  weekday_name_short: fn(Weekday) -&gt; String,\n  day_with_suffix: fn(Int) -&gt; String,\n)\n\n\nSynonyms:\nrada/date.Language\nrada/date Language","url":"rada/date.html#Language"},{"doc":"rada/date","title":"Month","content":"pub type Month {\n  Jan\n  Feb\n  Mar\n  Apr\n  May\n  Jun\n  Jul\n  Aug\n  Sep\n  Oct\n  Nov\n  Dec\n}\n Represents the 12 months of the year.\nJan\n\n\nFeb\n\n\nMar\n\n\nApr\n\n\nMay\n\n\nJun\n\n\nJul\n\n\nAug\n\n\nSep\n\n\nOct\n\n\nNov\n\n\nDec\n\n\nSynonyms:\nrada/date.Month\nrada/date Month","url":"rada/date.html#Month"},{"doc":"rada/date","title":"Unit","content":"pub type Unit {\n  Years\n  Months\n  Weeks\n  Days\n}\n Used in `add` and `diff` operations to specify natural increments as needed.\nYears\n\n\nMonths\n\n\nWeeks\n\n\nDays\n\n\nSynonyms:\nrada/date.Unit\nrada/date Unit","url":"rada/date.html#Unit"},{"doc":"rada/date","title":"Weekday","content":"pub type Weekday {\n  Mon\n  Tue\n  Wed\n  Thu\n  Fri\n  Sat\n  Sun\n}\n Represents the 7 days of the week.\nMon\n\n\nTue\n\n\nWed\n\n\nThu\n\n\nFri\n\n\nSat\n\n\nSun\n\n\nSynonyms:\nrada/date.Weekday\nrada/date Weekday","url":"rada/date.html#Weekday"},{"doc":"rada/date","title":"add","content":"pub fn add(date: Date, count: Int, unit: Unit) -&gt; Date\n Get a past or future date by adding a number of units to a date.\n \n \n add(Weeks, -2, from_calendar_date(2018, Sep, 26))\n     == from_calendar_date(2018, Sep, 12)\n \n \n When adding `Years` or `Months`, day values are clamped to the end of the\n month if necessary.\n \n \n add(Months, 1, from_calendar_date(2000, Jan, 31))\n     == from_calendar_date(2000, Feb, 29)\n \nSynonyms:\nrada/date.add\nrada/date add","url":"rada/date.html#add"},{"doc":"rada/date","title":"ceiling","content":"pub fn ceiling(date: Date, interval: Interval) -&gt; Date\n Round up a date to the beginning of the closest interval. The resulting\n date will be greater than or equal to the one provided.\n \n \n ceiling(Tuesday, from_calendar_date(2018, May, 11))\n     == from_calendar_date(2018, May, 15)\n \nSynonyms:\nrada/date.ceiling\nrada/date ceiling","url":"rada/date.html#ceiling"},{"doc":"rada/date","title":"clamp","content":"pub fn clamp(value: Date, lower: Date, upper: Date) -&gt; Date\n Clamp a date within a range.\n \n \n let minimum = from_ordinal_date(1970, 1)\n let maximum = from_ordinal_date(2038, 1)\n \n clamp(from_ordinal_date(1969, 201), minimum, maximum)\n     == from_ordinal_date(1970, 1)\n \n \nSynonyms:\nrada/date.clamp\nrada/date clamp","url":"rada/date.html#clamp"},{"doc":"rada/date","title":"compare","content":"pub fn compare(date1: Date, date2: Date) -&gt; Order\n Compare two dates. This can be used as the compare function for\n `list.sort`.\n \n \n import gleam/ordering\n\n compare(from_ordinal_date(1970, 1), from_ordinal_date(2038, 1))\n     == ordering.Lt\n \nSynonyms:\nrada/date.compare\nrada/date compare","url":"rada/date.html#compare"},{"doc":"rada/date","title":"day","content":"pub fn day(date: Date) -&gt; Int\n The day of the month (1–31).\nSynonyms:\nrada/date.day\nrada/date day","url":"rada/date.html#day"},{"doc":"rada/date","title":"diff","content":"pub fn diff(unit: Unit, date1: Date, date2: Date) -&gt; Int\n Get the difference, as a number of whole units, between two dates.\n \n \n diff(Months, from_calendar_date(2020, Jan, 2), from_calendar_date(2020, Apr, 1))\n // -&gt; 2\n \nSynonyms:\nrada/date.diff\nrada/date diff","url":"rada/date.html#diff"},{"doc":"rada/date","title":"floor","content":"pub fn floor(date: Date, interval: Interval) -&gt; Date\n Round down a date to the beginning of the closest interval. The resulting\n date will be less than or equal to the one provided.\n \n \n floor(Tuesday, from_calendar_date(2018, May, 11))\n         == from_calendar_date(2018, May, 8)\n \nSynonyms:\nrada/date.floor\nrada/date floor","url":"rada/date.html#floor"},{"doc":"rada/date","title":"format","content":"pub fn format(date: Date, pattern: String) -&gt; String\n Format a date using a string as a template.\n \n \n from_ordinal_date(1970, 1)\n |&gt; format(&quot;EEEE, d MMMM y&quot;)\n // -&gt; &quot;Thursday, 1 January 1970&quot;\n \n \n Alphabetic characters in the template represent date information; the number of\n times a character is repeated specifies the form of a name (e.g. `&quot;Tue&quot;`,\n `&quot;Tuesday&quot;`) or the padding of a number (e.g. `&quot;1&quot;`, `&quot;01&quot;`).\n \n Alphabetic characters can be escaped within single-quotes; a single-quote can\n be escaped as a sequence of two single-quotes, whether appearing inside or\n outside an escaped sequence.\n \n Templates are based on Date Format Patterns in [Unicode Technical\n Standard #35][uts35]. Only the following subset of formatting characters\n are available:\n \n     &quot;y&quot; -- year\n \n     &quot;Y&quot; -- week-numbering year\n \n     &quot;Q&quot; -- quarter\n \n     &quot;M&quot; -- month (number or name)\n \n     &quot;w&quot; -- week number\n \n     &quot;d&quot; -- day\n \n     &quot;D&quot; -- ordinal day\n \n     &quot;E&quot; -- weekday name\n \n     &quot;e&quot; -- weekday number\n \n [uts35]: http://www.unicode.org/reports/tr35/tr35-43/tr35-dates.html#Date_Format_Patterns\n \n The non-standard pattern field &quot;ddd&quot; is available to indicate the day of the\n month with an ordinal suffix (e.g. `&quot;1st&quot;`, `&quot;15th&quot;`), as the current standard\n does not include such a field.\nSynonyms:\nrada/date.format\nrada/date format","url":"rada/date.html#format"},{"doc":"rada/date","title":"format_with_language","content":"pub fn format_with_language(\n  date: Date,\n  language: Language,\n  pattern_text: String,\n) -&gt; String\n Format a date in a custom language using a string as a template.\n \n \n // Assuming that `french_lang` is a custom `Language` value\n from_ordinate_date(1970, 1)\n |&gt; format_with_language(french_lang, &quot;EEEE, ddd MMMM y&quot;)\n // -&gt; &quot;jeudi, 1er janvier 1970&quot;\n \nSynonyms:\nrada/date.format_with_language\nrada/date format_with_language","url":"rada/date.html#format_with_language"},{"doc":"rada/date","title":"from_calendar_date","content":"pub fn from_calendar_date(\n  year: Int,\n  month: Month,\n  day: Int,\n) -&gt; Date\n Create a date from a [calendar date][gregorian]: a year, month, and day of\n the month. Out-of-range day values will be clamped.\n \n \n from_calendar_date(2018, Sep, 26)\n \n \n [gregorian]: https://en.wikipedia.org/wiki/Proleptic_Gregorian_calendar\nSynonyms:\nrada/date.from_calendar_date\nrada/date from_calendar_date","url":"rada/date.html#from_calendar_date"},{"doc":"rada/date","title":"from_iso_string","content":"pub fn from_iso_string(str: String) -&gt; Result(Date, String)\n Attempt to create a date from a string in [ISO 8601][iso8601] format.\n Calendar dates, week dates, and ordinal dates are all supported in extended\n and basic format.\n \n \n // calendar date\n from_iso_string(&quot;2018-09-26&quot;) == Ok(from_calendar_date(2018, Sep, 26))\n \n // week date\n from_iso_string(&quot;2018-W39-3&quot;) == Ok(from_week_date(2018, 39, Wed))\n \n // ordinal date\n from_iso_string(&quot;2018-269&quot;) == Ok(from_ordinal_date(2018, 269))\n \n \n The string must represent a valid date; unlike `from_calendar_date` and\n friends, any out-of-range values will fail to produce a date.\n \n \n from_iso_string(&quot;2018-02-29&quot;) == Error(&quot;Invalid calendar date (2018, 2, 29)&quot;)\n \n \n [iso8601]: https://en.wikipedia.org/wiki/ISO_8601\nSynonyms:\nrada/date.from_iso_string\nrada/date from_iso_string","url":"rada/date.html#from_iso_string"},{"doc":"rada/date","title":"from_ordinal_date","content":"pub fn from_ordinal_date(year: Int, ordinal: Int) -&gt; Date\n Create a date from an [ordinal date][ordinaldate]: a year and day of the\n year. Out-of-range day values will be clamped.\n \n \n from_ordinal_date(2018, 269)\n \n \n [ordinaldate]: https://en.wikipedia.org/wiki/Ordinal_date\nSynonyms:\nrada/date.from_ordinal_date\nrada/date from_ordinal_date","url":"rada/date.html#from_ordinal_date"},{"doc":"rada/date","title":"from_rata_die","content":"pub fn from_rata_die(rd: Int) -&gt; Date\n [Rata Die][ratadie] where the number 1 represents the date **1 January 0001**.\n [Rata Die][ratadie] is a system for assigning numbers to calendar days,\n \n You can losslessly convert a `Date` to and from an `Int` representing the date\n in Rata Die. This makes it a convenient representation for transporting dates\n or using them as comparables. For all date values:\n \n \n { date |&gt; to_rata_die |&gt; from_rata_die } == date\n \n\n [ratadie]: https://en.wikipedia.org/wiki/Rata_Die\nSynonyms:\nrada/date.from_rata_die\nrada/date from_rata_die","url":"rada/date.html#from_rata_die"},{"doc":"rada/date","title":"from_week_date","content":"pub fn from_week_date(\n  week_year: Int,\n  week_number: Int,\n  weekday: Weekday,\n) -&gt; Date\n Create a date from an [ISO week date][weekdate]: a week-numbering year,\n week number, and weekday. Out-of-range week number values will be clamped.\n \n \n from_week_date(2018, 39, Wed)\n \n \n [weekdate]: https://en.wikipedia.org/wiki/ISO_week_date\nSynonyms:\nrada/date.from_week_date\nrada/date from_week_date","url":"rada/date.html#from_week_date"},{"doc":"rada/date","title":"is_between","content":"pub fn is_between(value: Date, lower: Date, upper: Date) -&gt; Bool\n Test if a date is within a range, inclusive of the range values.\n \n \n let minimum = from_ordinal_date(1970, 1)\n let maximum = from_ordinal_date(2038, 1)\n \n is_between(minimum, maximum, from_ordinal_date(1969, 201))\n     == False\n \nSynonyms:\nrada/date.is_between\nrada/date is_between","url":"rada/date.html#is_between"},{"doc":"rada/date","title":"max","content":"pub fn max(date1: Date, date2: Date) -&gt; Date\n Find the greater of two dates.\n \n \n max(from_ordinal_date(1970, 1), from_ordinal_date(2038, 1))\n     == from_ordinal_date(2038, 1)\n \nSynonyms:\nrada/date.max\nrada/date max","url":"rada/date.html#max"},{"doc":"rada/date","title":"min","content":"pub fn min(date1: Date, date2: Date) -&gt; Date\n Find the lesser of two dates.\n \n \n min(from_ordinal_date(1970, 1), from_ordinal_date(2038, 1))\n     == from_ordinal_date(1970, 1)\n \nSynonyms:\nrada/date.min\nrada/date min","url":"rada/date.html#min"},{"doc":"rada/date","title":"month","content":"pub fn month(date: Date) -&gt; Month\n The month as [`Month`](#Month) value (`Jan`–`Dec`).\nSynonyms:\nrada/date.month\nrada/date month","url":"rada/date.html#month"},{"doc":"rada/date","title":"month_number","content":"pub fn month_number(date: Date) -&gt; Int\n The month number (1–12).\nSynonyms:\nrada/date.month_number\nrada/date month_number","url":"rada/date.html#month_number"},{"doc":"rada/date","title":"month_to_number","content":"pub fn month_to_number(month: Month) -&gt; Int\n Converts the month values `Jan`–`Dec` to 1–12.\nSynonyms:\nrada/date.month_to_number\nrada/date month_to_number","url":"rada/date.html#month_to_number"},{"doc":"rada/date","title":"number_to_month","content":"pub fn number_to_month(month_number: Int) -&gt; Month\n Converts the numbers 1–12 to `Jan`–`Dec`. The input is clamped to the range 1-12 before conversion.\nSynonyms:\nrada/date.number_to_month\nrada/date number_to_month","url":"rada/date.html#number_to_month"},{"doc":"rada/date","title":"number_to_weekday","content":"pub fn number_to_weekday(weekday_number: Int) -&gt; Weekday\n Converts the numbers 1–7 to `Mon`–`Sun`. The input is clamped to the range 1-7 before conversion.\nSynonyms:\nrada/date.number_to_weekday\nrada/date number_to_weekday","url":"rada/date.html#number_to_weekday"},{"doc":"rada/date","title":"ordinal_day","content":"pub fn ordinal_day(date: Date) -&gt; Int\n The day of the year (1–366).\nSynonyms:\nrada/date.ordinal_day\nrada/date ordinal_day","url":"rada/date.html#ordinal_day"},{"doc":"rada/date","title":"quarter","content":"pub fn quarter(date: Date) -&gt; Int\n The quarter of the year (1–4).\nSynonyms:\nrada/date.quarter\nrada/date quarter","url":"rada/date.html#quarter"},{"doc":"rada/date","title":"range","content":"pub fn range(\n  interval: Interval,\n  step: Int,\n  start_date: Date,\n  until_date: Date,\n) -&gt; List(Date)\n Create a list of dates, at rounded intervals, increasing by a step value,\n between two dates. The list will start on or after the first date, and end\n before the second date.\n \n \n let start = from_calendar_date(2018, May, 8)\n let until = from_calendar_date(2018, May, 14)\n\n range(Day, 2, start, until)\n     == [ from_calendar_date(2018, May, 8)\n        , from_calendar_date(2018, May, 10)\n        , from_calendar_date(2018, May, 12)\n        ]\n \nSynonyms:\nrada/date.range\nrada/date range","url":"rada/date.html#range"},{"doc":"rada/date","title":"to_iso_string","content":"pub fn to_iso_string(date: Date) -&gt; String\n Convert a date to a string in ISO 8601 extended format.\n \n \n from_calendar_date(2001, Jan, 1)\n |&gt; to_iso_string\n // -&gt; &quot;2001-01-01&quot;\n \nSynonyms:\nrada/date.to_iso_string\nrada/date to_iso_string","url":"rada/date.html#to_iso_string"},{"doc":"rada/date","title":"to_rata_die","content":"pub fn to_rata_die(date: Date) -&gt; Int\n Convert a date to its number representation in Rata Die (see\n [`from_rata_die`](#from_rata_die)). For all date values:\n \n \n { date |&gt; to_rata_die |&gt; from_rata_die } == date\n \nSynonyms:\nrada/date.to_rata_die\nrada/date to_rata_die","url":"rada/date.html#to_rata_die"},{"doc":"rada/date","title":"today","content":"pub fn today() -&gt; Date\n Get the current local date\nSynonyms:\nrada/date.today\nrada/date today","url":"rada/date.html#today"},{"doc":"rada/date","title":"week_number","content":"pub fn week_number(date: Date) -&gt; Int\n The ISO week number of the year (1–53).\nSynonyms:\nrada/date.week_number\nrada/date week_number","url":"rada/date.html#week_number"},{"doc":"rada/date","title":"week_year","content":"pub fn week_year(date: Date) -&gt; Int\n The ISO week-numbering year. This is not always the same as the calendar year.\nSynonyms:\nrada/date.week_year\nrada/date week_year","url":"rada/date.html#week_year"},{"doc":"rada/date","title":"weekday","content":"pub fn weekday(date: Date) -&gt; Weekday\n The weekday as a [`Weekday`](#Weekday) value (`Mon`–`Sun`).\nSynonyms:\nrada/date.weekday\nrada/date weekday","url":"rada/date.html#weekday"},{"doc":"rada/date","title":"weekday_number","content":"pub fn weekday_number(date: Date) -&gt; Int\n The weekday number (1–7), beginning with Monday.\n\n \n from_calendar_date(2020, 03, 04) |&gt; weekday_number\n // -&gt; 3\n \nSynonyms:\nrada/date.weekday_number\nrada/date weekday_number","url":"rada/date.html#weekday_number"},{"doc":"rada/date","title":"with_ordinal_suffix","content":"pub fn with_ordinal_suffix(value: Int) -&gt; String\n Convert an integer into an English ordinal number string (like `&quot;4th&quot;`).\n \n \n with_ordinal_suffix(21) == &quot;21st&quot;\n with_ordinal_suffix(42) == &quot;42nd&quot;\n with_ordinal_suffix(0) == &quot;0th&quot;\n with_ordinal_suffix(23) == &quot;23rd&quot;\n with_ordinal_suffix(-1) == &quot;-1st&quot;\n \n \nSynonyms:\nrada/date.with_ordinal_suffix\nrada/date with_ordinal_suffix","url":"rada/date.html#with_ordinal_suffix"},{"doc":"rada/date","title":"year","content":"pub fn year(date: Date) -&gt; Int\n The calendar year.\n\n \n from_calendar_date(2020, 03, 04) |&gt; year\n // -&gt; 2020\n \nSynonyms:\nrada/date.year\nrada/date year","url":"rada/date.html#year"},{"doc":"rada/date","title":"rada/date","content":" This module provides a simple [`Date`](#Date) type for working with dates without times or zones.\n\n The module uses the [Rata Die][ratadie] system to represent dates in the standard Gregorian Calendar.\n The number 1 represents the date **1 January 0001** and all other dates are represented as positive\n or negative numbers relative to that date.\n\n [ratadie]: https://en.wikipedia.org/wiki/Rata_Die","url":"rada/date.html"},{"doc":"example","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nexample.main\nexample main","url":"example.html#main"},{"doc":"example","title":"example","content":"","url":"example.html"}]);